Function cap_primitives::fs::read_dir [−][src]
Construct a ReadDir to iterate over the contents of a directory,
ensuring that the resolution of the path never escapes the directory
tree rooted at start.